function [ ] = AP_Bounding_Functions(i)
%%% AP (a priori) Bounding Functions %%%
% Input
%   i=1 ===>  alpha = [pi/2 , 1.6]
%   i=2 ===>  alpha = [ 1.6 , 1.7]
%   i=3 ===>  alpha = [ 1.7 , 1.8]
%   i=4 ===>  alpha = [ 1.8 , 1.9]

	cd ..
	addpath('Intlab_V10.1')
	startup
	cd('Middle')
    %%% This file uses the techniques in the paper: 
    %       ``Stability and uniqueness of SOPS to Wright's equation''
    %   To create I_\alpha-exhaustive collections of bounding functions
    addpath('Floquet-Wright')


    % Note: There are compatibility issues with the code from papers: 
    %   ``Stability and uniqueness of SOPS to Wright's equation''
    %   ``A proof of Jones' conjecture''
    %   e.g. There are functions "Prune" and "Branch" defined in both libraries


    % We create a list of alpha-intervals. 
    alpha_pi_2  = intval('pi')/2;
    alpha_1p6   = intval('1.6');
    alpha_1p7   = intval('1.7');
    alpha_1p8   = intval('1.8');
    alpha_1p9   = intval('1.9');

    List_alpha = {  infsup(  inf(alpha_pi_2),       sup(alpha_1p6)  ),
                    infsup(  inf(alpha_1p6),        sup(alpha_1p7)  ),
                    infsup(  inf(alpha_1p7),        sup(alpha_1p8)  ),
                    infsup(  inf(alpha_1p8),        sup(alpha_1p9)  )};

    alpha = List_alpha{i}
    
    
    % We create a string corresponding to alpha, for our output files
    alpha_str_1  = num2str(alpha.inf,3);
    alpha_str_2  = num2str(alpha.sup,3);
    alpha_str    = strcat('_',alpha_str_1,'-',alpha_str_2);




    % We define all of the needed computational parameters
        res = 32;   % res = n_time ;
        rep = 4;    % N_Prune
        tmin =-4;
        epsilon_1 = 0.05;   %%%% Should be 0.05
        epsilon_2 = 0.05;   %%%% Should be 0.05
        N_Period = 10;
        % The computational parameters are as follows:
        % i0 =2;
        % j0 =20;

    % A. We import the computational results from [9, Alg. 5.1]


   
        % We run ALGORITHM 5.1  from paper: 
        %   ``Stability and uniqueness of SOPS to Wright's equation''
        % NOT TO BE CONFUSED WITH ALGORITHM 6.1  from paper: 
        %   ``A proof of Jones' conjecture''

        tic
        [ List_X_p, List_X_I, List_Q, List_Qbar , inspected ] = BranchAndBound( alpha, res, rep , tmin,  epsilon_1 ,epsilon_2,N_Period );
        time_bounding_functions = toc 



        cd('Data')
        save(strcat('var_AP_Bounding_Functions',alpha_str,'.mat'));
        

   
end
    
