classdef Cube < matlab.mixin.Copyable
%CUBE       -- See Definition 2.7
%   We compute F, DF, the Krawczyk operator, etc as class methods
    
    properties
        alpha   % Parameter
        omega   % Frequency
        A       % Cosine (real)      Coefficients
        B       % Sine   (imaginary) Coefficients 
        M       % Truncation dimension
        C0      % Tail coefficient
        s       % Tail Decay Rate 
        
        Zeros   % an MxM matrix of Zeros
        linear  % a column vector 
        

        
        % U_{\omega} = exp{ - i k omega} * c_k
        % (See Section 2.2)
        UR      % The Real part of U_{\omega}
        UI      % The imaginary part of U_{\omega}

        
    end% Properties
    
    methods
        % Constructor Method
        function obj = Cube(alpha,omega,A,B,M) 
            if nargin > 0 %if Cube is called with more than one argument.
                obj.alpha = alpha;
                obj.omega = omega;
                obj.A = A;
                obj.B= B;
                obj.M= M;
                
                obj.Zeros =intval(zeros(M));  
                obj.linear = transpose(1:M);               
                obj.update
            end
        end 
        function  update(obj) 
            obj.UR = cos( obj.omega*obj.linear );
            obj.UI = -sin( obj.omega*obj.linear );
        end
        function  Double(obj) 
            obj.Zeros = mid(obj.Zeros );
            obj.alpha = mid(obj.alpha);
        end
    end% Methods
    
end

