function [ dw_R, dw_I, da_R , da_I, db_R, db_I ] = DFeval( X  )
%DFEVAL     -- This is <<< ~pi_M o DF o ~i'_M   >>> 
%           -- See Proposition 2.6 & Definition 3.1
%       The output is a 2M x 2M real(interval)-matrix




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%
%%%  OMEGA   %%%
%%%%%%%%%%%%%%%%%

% We evaluate the Omega derivative. 

%%%%%%%%%%%%%%%%%
%%%  Linear   %%%
%%%%%%%%%%%%%%%%%

% linear part

% We create the coefficients ( \alpha^{-1} - U_w )
w_R = X.linear .*  X.UI;
w_I = X.linear .* (1/X.alpha - X.UR);
% We multiply the coefficients by c_k.
linear_w_R = w_R .* X.A - w_I .* X.B;
linear_w_I = w_I .* X.A + w_R .* X.B;



% We calculate the finite sum << N1w >> below
%
%          M
%    -i SUM     j e^{-i w j} c_j    c_{k-j}
%         j=1   

% We create a matrix which represents C_{k-j}

a=X.A;
b=X.B;
N1wA=X.Zeros;
N1wB=X.Zeros;
for k=1:X.M
    a = [0 ; a(1:end-1)];
    b = [0 ; b(1:end-1)];
    N1wA(:,k)=a;
    N1wB(:,k)=b;
end

% We calculate << E^{-i w j) c_j  >> to help with defining N1
UC_R = X.UR .* X.A  - X.B .* X.UI;
UC_I = X.A  .* X.UI + X.B .* X.UR;

% We calculate the sum / matrix product.
N1wR_pre = ( N1wA*( X.linear .* UC_R) - N1wB*( X.linear .* UC_I));
N1wI_pre = ( N1wB*( X.linear .* UC_R) + N1wA*( X.linear .* UC_I));

% We multiply by -i
N1wR =   N1wI_pre;
N1wI = - N1wR_pre;




%%%%%%%%%%%%%%%%%%%%%%%
% We calculate the trucated sum << N2w >> below
%
%          M
%   -i  SUM     ( lambda_1 - lambda_2)  c_j^* c_{j+k}
%         j=1   
%
%                         lambda_1 = (j+k)e^{-iw(j+k)}
%  where:                 lambda_2 =   j  e^{i w j}
%                         lambda   =  lambda_1 - lambda_2

% We create a matrix which represents << lambda  C_{k+j} >> :: N2A & N2B
a= X.A;
b= X.B;

N2A=X.Zeros;
N2B=X.Zeros;
%   lambda_1 =   (j+k)e^{-iw(j+k)}
lambda1_R = X.linear .* X.UR;
lambda1_I = X.linear .* X.UI;

for j=1: X.M-1
    lambda1_R(1)=[];
    lambda1_I(1)=[];
    
    % Subtract lambda_2 =   j  e^{i w j}  :: Note this is U_w^*.
    lambda_R = lambda1_R - j* X.UR(j);
    lambda_I = lambda1_I + j* X.UI(j);
    
    lambda_R(X.M,1)=0;
    lambda_I(X.M,1)=0;
    
    a = [a(2:end);0];
    b = [b(2:end);0];
    
    % We calculate << lambda  C_{k+j} >>
    N2A(:,j) = lambda_R.*a - lambda_I.*b;
    N2B(:,j) = lambda_I.*a + lambda_R.*b;
end

% We multiply << lambda  C_{k+j} >> by C_j^*
N2wR_pre = N2A*X.A -(- N2B*X.B);
N2wI_pre = N2B*X.A + (-N2A*X.B);

% We multiply by -i
N2wR = N2wI_pre;
N2wI =-N2wR_pre;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%We define the omega derivative
dw_R = linear_w_R + N1wR + N2wR;
dw_I = linear_w_I + N1wI + N2wI;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% We calculate the dc derivatives. 


%%%%%%%%%%%%%%%%%
%%%  Linear   %%%
%%%%%%%%%%%%%%%%%
% The linear Part
linear_a_R_pre =  X.UR;
linear_a_I_pre = (X.omega/X.alpha) * X.linear +  X.UI;

linear_a_R = diag(linear_a_R_pre);
linear_a_I = diag(linear_a_I_pre);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% We evaluate the Gamma _1 part
% gamma_1 = e^{-iw(n+k)} + e^{+iwn}
a = X.A;
b = X.B;

% We create the << e^{-iw(n+k)} >> part
lambda_1R = X.UR; 
lambda_1I = X.UI; 

gC_1R = X.Zeros;
gC_1I = X.Zeros;
for n = 1:X.M-1
    a = [a(2:end);0];
    b = [b(2:end);0];

    lambda_1R = [lambda_1R(2:end);0];
    lambda_1I = [lambda_1I(2:end);0];
   
    % Subtract the << e^{+i w n} >> part  ::: Note U_w^*
    gamma_1R = lambda_1R + X.UR(n);
    gamma_1I = lambda_1I - X.UI(n);
    
    % We calculate gamma_1 * c_{n+k}
    gC_1R(:,n) = gamma_1R .* a - gamma_1I .* b;
    gC_1I(:,n) = gamma_1I .* a + gamma_1R .* b;
    
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% We create a matrix which represents  << gamma_2  c_{\pm(n-k)} >> part of the derivative

% This part being multiplied by either c_{k-n} or c_{n-k}^* 
% makes for a symmetric / anti-symmetric matrix. 

% gamma_2 = e^{-iw n} + e^{+iw(n-k)}

% We make the c_{k-n} part - which will be modified.
a = X.A;
b = X.B;

% We create the << e^{iw(n-k)} >> part
% We don't start with the entire vector . 
lambda_2R = X.UR(1:X.M-1);
lambda_2I = X.UI(1:X.M-1);

% These matricies contain the   parts
LAMBDA_R = X.Zeros;
LAMBDA_I = X.Zeros;

% These matricies contain the c_{k-n} or c_{n-k}^*  parts
gC_2R= X.Zeros;
gC_2I= X.Zeros;

for k=1:X.M
    %%% Lambda only calculation %%%
    lambda_2R = [0;lambda_2R(1:X.M-1)];
    lambda_2I = [0;lambda_2I(1:X.M-1)];
    
    LAMBDA_R(:,k) = lambda_2R ;
    LAMBDA_I(:,k) = lambda_2I ;

    %%% gC_2 only calculation %%%
    a = [0 ; a(1:end-1)];
    b = [0 ; b(1:end-1)];
   
    gC_2R(:,k)=a;
    gC_2I(:,k)=b;
end

% We follow through with the relevant symmetry
LAMBDA_R=LAMBDA_R+transpose(LAMBDA_R);
        % We follow through with the relevant ANTI-symmetry
        LAMBDA_I=LAMBDA_I-transpose(LAMBDA_I);
        
% We follow through with the relevant symmetry
gCT_2R = gC_2R + transpose(gC_2R);
        % We follow through with the relevant ANTI-symmetry
        gCT_2I = gC_2I - transpose(gC_2I);
        
% We finish create a matrix which represents  << gamma_2  >> by adding on
% the  e^{-iw n} part 
gamma_2R = X.Zeros;
gamma_2I = X.Zeros;
for n = 1:X.M
    gamma_2R(:,n) = LAMBDA_R(:,n) + X.UR(n);
    gamma_2I(:,n) = LAMBDA_I(:,n) + X.UI(n);
end

% We finish the matrix representing  << gamma_2  c_{\pm(n-k)} >> 
% This uses elementwise multiplication of two matricies. 
gC_2R = gamma_2R.*gCT_2R - gamma_2I .* gCT_2I;
gC_2I = gamma_2I.*gCT_2R + gamma_2R .* gCT_2I;






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%%%% Prepare Final Answer  %%%%%%

%  dc_a = linear_c+A+B);
da_R = linear_a_R + gC_1R +  gC_2R;
da_I = linear_a_I + gC_1I +  gC_2I;

%  dc_b = i*(linear_c-A+B);
db_R = -linear_a_I + gC_1I - gC_2I;
db_I = linear_a_R - gC_1R + gC_2R;






end

