function [  ] = PhaseCondition( X )
%PhaseCondition     -- This takes a cube, and rotates the Fourier
%                       coefficients so that we can assume that the 
%                       first fourier coefficient is real
%                   -- See Algorithm 5.3  --

    % 1. We calculate the angle we need to rotate the cube.     
            % usually B1 < 0
        A1 = X.A(1);
        B1 = X.B(1);
    %   We define theta.
        if A1 > 0
            theta = atan( B1/A1 ) ;
        elseif A1 < 0        
            theta = atan( B1/A1 )+intval('pi');
        elseif     B1 > 0
            theta = -atan( A1/B1 )+intval('pi')/2;
        elseif B1 < 0
            theta = -atan( A1/B1 )-intval('pi')/2;
        else
            theta = infsup(-1,1)*intval('pi');
        end
    
   
% 2. We rotate the higher Fourier coefficients.                 
        
        % We define the rotated values for the first mode
        A1_new = sqrt( X.A(1)^2 + X.B(1)^2);
        B1_new = intval(0);

        % We create 1xM interval vectors containing cos(k*theta) ; sin(k*theta)
        COS_th = transpose(cos( (1:X.M)*theta));
        SIN_th = transpose(sin( (1:X.M)*theta));

        % We define the rotated values for the higher modes (k \geq 2)
        A =  COS_th.*X.A + SIN_th.*X.B;
        B = -SIN_th.*X.A + COS_th.*X.B;

        % We impose the first mode conditions
        A(1) = A1_new;
        B(1) = B1_new;
        
        % We replace the old modes with the rotated modes. 
        X.A = A;
        X.B = B;

% 3.  We keep the tail, and then the frequency the same.
        % nothing to do.
end

